@@ -42,11 +42,12 @@
 #define PCL_SAMPLE_CONSENSUS_IMPL_SAC_MODEL_NORMAL_SPHERE_H_
 
 #include <pcl/sample_consensus/sac_model_normal_sphere.h>
+#include <pcl/common/common.h> // for getAngle3D
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointT, typename PointNT> void
 pcl::SampleConsensusModelNormalSphere<PointT, PointNT>::selectWithinDistance (
-      const Eigen::VectorXf &model_coefficients, const double threshold, std::vector<int> &inliers)
+      const Eigen::VectorXf &model_coefficients, const double threshold, Indices &inliers)
 {
   if (!normals_)
   {
@@ -64,51 +65,50 @@ pcl::SampleConsensusModelNormalSphere<PointT, PointNT>::selectWithinDistance (
 
   // Obtain the sphere center
   Eigen::Vector4f center = model_coefficients;
-  center[3] = 0;
+  center[3] = 0.0f;
 
-  int nr_p = 0;
-  inliers.resize (indices_->size ());
-  error_sqr_dists_.resize (indices_->size ());
+  inliers.clear ();
+  error_sqr_dists_.clear ();
+  inliers.reserve (indices_->size ());
+  error_sqr_dists_.reserve (indices_->size ());
 
-  // Iterate through the 3d points and calculate the distances from them to the plane
-  for (size_t i = 0; i < indices_->size (); ++i)
+  // Iterate through the 3d points and calculate the distances from them to the sphere
+  for (std::size_t i = 0; i < indices_->size (); ++i)
   {
     // Calculate the distance from the point to the sphere center as the difference between
     // dist(point,sphere_origin) and sphere_radius
-    Eigen::Vector4f p (input_->points[(*indices_)[i]].x, 
-                       input_->points[(*indices_)[i]].y,
-                       input_->points[(*indices_)[i]].z, 
-                       0);
-
-    Eigen::Vector4f n (normals_->points[(*indices_)[i]].normal[0], 
-                       normals_->points[(*indices_)[i]].normal[1], 
-                       normals_->points[(*indices_)[i]].normal[2], 
-                       0);
+    Eigen::Vector4f p ((*input_)[(*indices_)[i]].x, 
+                       (*input_)[(*indices_)[i]].y,
+                       (*input_)[(*indices_)[i]].z, 
+                       0.0f);
 
     Eigen::Vector4f n_dir = p - center;
-    double d_euclid = fabs (n_dir.norm () - model_coefficients[3]);
+    const double weighted_euclid_dist = (1.0 - normal_distance_weight_) * std::abs (n_dir.norm () - model_coefficients[3]);
+    if (weighted_euclid_dist > threshold) // Early termination: cannot be an inlier
+      continue;
 
-    // Calculate the angular distance between the point normal and the plane normal
-    double d_normal = fabs (getAngle3D (n, n_dir));
+    // Calculate the angular distance between the point normal and the sphere normal
+    Eigen::Vector4f n ((*normals_)[(*indices_)[i]].normal[0], 
+                       (*normals_)[(*indices_)[i]].normal[1], 
+                       (*normals_)[(*indices_)[i]].normal[2], 
+                       0.0f);
+    double d_normal = std::abs (getAngle3D (n, n_dir));
     d_normal = (std::min) (d_normal, M_PI - d_normal);
 
-    double distance = fabs (normal_distance_weight_ * d_normal + (1 - normal_distance_weight_) * d_euclid); 
+    double distance = std::abs (normal_distance_weight_ * d_normal + weighted_euclid_dist);
     if (distance < threshold)
     {
       // Returns the indices of the points whose distances are smaller than the threshold
-      inliers[nr_p] = (*indices_)[i];
-      error_sqr_dists_[nr_p] = static_cast<double> (distance);
-      ++nr_p;
+      inliers.push_back ((*indices_)[i]);
+      error_sqr_dists_.push_back (static_cast<double> (distance));
     }
   }
-  inliers.resize (nr_p);
-  error_sqr_dists_.resize (nr_p);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-template <typename PointT, typename PointNT> int
+template <typename PointT, typename PointNT> std::size_t
 pcl::SampleConsensusModelNormalSphere<PointT, PointNT>::countWithinDistance (
-      const Eigen::VectorXf &model_coefficients,  const double threshold)
+      const Eigen::VectorXf &model_coefficients,  const double threshold) const
 {
   if (!normals_)
   {
@@ -121,35 +121,36 @@ pcl::SampleConsensusModelNormalSphere<PointT, PointNT>::countWithinDistance (
     return(0);
 
 
-  // Obtain the shpere centroid
+  // Obtain the sphere centroid
   Eigen::Vector4f center = model_coefficients;
-  center[3] = 0;
+  center[3] = 0.0f;
 
-  int nr_p = 0;
+  std::size_t nr_p = 0;
 
-  // Iterate through the 3d points and calculate the distances from them to the plane
-  for (size_t i = 0; i < indices_->size (); ++i)
+  // Iterate through the 3d points and calculate the distances from them to the sphere
+  for (std::size_t i = 0; i < indices_->size (); ++i)
   {
     // Calculate the distance from the point to the sphere centroid as the difference between
     // dist(point,sphere_origin) and sphere_radius
-    Eigen::Vector4f p (input_->points[(*indices_)[i]].x, 
-                       input_->points[(*indices_)[i]].y, 
-                       input_->points[(*indices_)[i]].z, 
-                       0);
-
-    Eigen::Vector4f n (normals_->points[(*indices_)[i]].normal[0], 
-                       normals_->points[(*indices_)[i]].normal[1], 
-                       normals_->points[(*indices_)[i]].normal[2], 
-                       0);
+    Eigen::Vector4f p ((*input_)[(*indices_)[i]].x, 
+                       (*input_)[(*indices_)[i]].y, 
+                       (*input_)[(*indices_)[i]].z, 
+                       0.0f);
 
     Eigen::Vector4f n_dir = (p-center);
-    double d_euclid = fabs (n_dir.norm () - model_coefficients[3]);
-    //
-    // Calculate the angular distance between the point normal and the plane normal
-    double d_normal = fabs (getAngle3D (n, n_dir));
+    const double weighted_euclid_dist = (1.0 - normal_distance_weight_) * std::abs (n_dir.norm () - model_coefficients[3]);
+    if (weighted_euclid_dist > threshold) // Early termination: cannot be an inlier
+      continue;
+
+    // Calculate the angular distance between the point normal and the sphere normal
+    Eigen::Vector4f n ((*normals_)[(*indices_)[i]].normal[0], 
+                       (*normals_)[(*indices_)[i]].normal[1], 
+                       (*normals_)[(*indices_)[i]].normal[2], 
+                       0.0f);
+    double d_normal = std::abs (getAngle3D (n, n_dir));
     d_normal = (std::min) (d_normal, M_PI - d_normal);
 
-    if (fabs (normal_distance_weight_ * d_normal + (1 - normal_distance_weight_) * d_euclid) < threshold)
+    if (std::abs (normal_distance_weight_ * d_normal + weighted_euclid_dist) < threshold)
       nr_p++;
   }
   return (nr_p);
@@ -158,7 +159,7 @@ pcl::SampleConsensusModelNormalSphere<PointT, PointNT>::countWithinDistance (
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointT, typename PointNT> void
 pcl::SampleConsensusModelNormalSphere<PointT, PointNT>::getDistancesToModel (
-      const Eigen::VectorXf &model_coefficients, std::vector<double> &distances)
+      const Eigen::VectorXf &model_coefficients, std::vector<double> &distances) const
 {
   if (!normals_)
   {
@@ -175,51 +176,35 @@ pcl::SampleConsensusModelNormalSphere<PointT, PointNT>::getDistancesToModel (
 
   // Obtain the sphere centroid
   Eigen::Vector4f center = model_coefficients;
-  center[3] = 0;
+  center[3] = 0.0f;
 
   distances.resize (indices_->size ());
 
-  // Iterate through the 3d points and calculate the distances from them to the plane
-  for (size_t i = 0; i < indices_->size (); ++i)
+  // Iterate through the 3d points and calculate the distances from them to the sphere
+  for (std::size_t i = 0; i < indices_->size (); ++i)
   {
     // Calculate the distance from the point to the sphere as the difference between
     // dist(point,sphere_origin) and sphere_radius
-    Eigen::Vector4f p (input_->points[(*indices_)[i]].x, 
-                       input_->points[(*indices_)[i]].y, 
-                       input_->points[(*indices_)[i]].z, 
-                       0);
-
-    Eigen::Vector4f n (normals_->points[(*indices_)[i]].normal[0], 
-                       normals_->points[(*indices_)[i]].normal[1], 
-                       normals_->points[(*indices_)[i]].normal[2], 
-                       0);
+    Eigen::Vector4f p ((*input_)[(*indices_)[i]].x, 
+                       (*input_)[(*indices_)[i]].y, 
+                       (*input_)[(*indices_)[i]].z, 
+                       0.0f);
 
     Eigen::Vector4f n_dir = (p-center);
-    double d_euclid = fabs (n_dir.norm () - model_coefficients[3]);
-    //
-    // Calculate the angular distance between the point normal and the plane normal
-    double d_normal = fabs (getAngle3D (n, n_dir));
+    const double weighted_euclid_dist = (1.0 - normal_distance_weight_) * std::abs (n_dir.norm () - model_coefficients[3]);
+
+    // Calculate the angular distance between the point normal and the sphere normal
+    Eigen::Vector4f n ((*normals_)[(*indices_)[i]].normal[0], 
+                       (*normals_)[(*indices_)[i]].normal[1], 
+                       (*normals_)[(*indices_)[i]].normal[2], 
+                       0.0f);
+    double d_normal = std::abs (getAngle3D (n, n_dir));
     d_normal = (std::min) (d_normal, M_PI - d_normal);
 
-    distances[i] = fabs (normal_distance_weight_ * d_normal + (1 - normal_distance_weight_) * d_euclid);
+    distances[i] = std::abs (normal_distance_weight_ * d_normal + weighted_euclid_dist);
   }
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-template <typename PointT, typename PointNT> bool 
-pcl::SampleConsensusModelNormalSphere<PointT, PointNT>::isModelValid (const Eigen::VectorXf &model_coefficients)
-{
-  if (!SampleConsensusModel<PointT>::isModelValid (model_coefficients))
-    return (false);
-
-  if (radius_min_ != -std::numeric_limits<double>::max() && model_coefficients[3] < radius_min_)
-    return (false);
-  if (radius_max_ != std::numeric_limits<double>::max() && model_coefficients[3] > radius_max_)
-    return (false);
-
-  return (true);
-}
-
 #define PCL_INSTANTIATE_SampleConsensusModelNormalSphere(PointT, PointNT) template class PCL_EXPORTS pcl::SampleConsensusModelNormalSphere<PointT, PointNT>;
 
 #endif    // PCL_SAMPLE_CONSENSUS_IMPL_SAC_MODEL_NORMAL_SPHERE_H_
